# Dictionary of default parameters
vis_params_dict = {
    'df_S':100, 
    'df_K':100,
    'df_K1':95,
    'df_K2':105,
    'df_K3':105,
    'df_K4':105,
    'df_G1':90,
    'df_G2':100,
    'df_G3':110,
    'df_H':105,
    'df_R':0,
    'df_T':0.25,
    'df_T1':0.25,
    'df_T2':0.25,
    'df_T3':0.25,
    'df_T4':0.25,
    'df_r':0.005,
    'df_b':0.005,
    'df_q':0,
    'df_sigma':0.2,
    'df_eta':1,
    'df_phi':1,
    'df_barrier_direction':'down',
    'df_knock':'in',    
    'df_option':'call',
    'df_option1':'call',
    'df_option2':'call',
    'df_option3':'call',
    'df_option4':'call',
    'df_direction':'long',
    'df_value':False,
    'df_ratio':2,
    'df_refresh':'Std',
    'df_combo_payoff':'straddle',
    'df_price_shift':0.25,
    'df_price_shift_type':'avg',
    'df_vol_shift':0.001,           
    'df_ttm_shift':1/365,
    'df_rate_shift':0.0001,
    'df_greek':'delta',
    'df_num_sens':False,
    'df_interactive':False,
    'df_notebook':True,
    'df_colorscheme':'jet',
    'df_colorintensity':1,
    'df_size3d':(15, 12),
    'df_size2d':(8, 6),
    'df_graphtype':'2D',
    'df_y_plot':'delta',
    'df_x_plot':'price',
    'df_time_shift':0.25,
    'df_cash':False,
    'df_axis':'price',
    'df_spacegrain':100,
    'df_azim':-60,
    'df_elev':30,
    'df_risk':True,
    'df_gif':False,
    'df_gif_folder_2d':'images/greeks2d',
    'df_gif_filename_2d':'greek2d',
    'df_gif_folder_3d':'images/greeks3d',
    'df_gif_filename_3d':'greek3d',
    'df_gif_frame_update':2,
    'df_gif_min_dist':9.0,
    'df_gif_max_dist':10.0,
    'df_gif_min_elev':10.0,
    'df_gif_max_elev':60.0,
    'df_gif_dpi':50,
    'df_gif_ms':100,
    'df_gif_start_azim':0,
    'df_gif_end_azim':360,
    'df_mpl_style':'seaborn-darkgrid',
 
     # List of default parameters used when refreshing 
     'df_params_list':[
         'S', 'K', 'K1', 'K2', 'K3', 'K4', 'G1', 'G2', 'G3', 'H', 'R', 
         'T', 'T1', 'T2', 'T3', 'T4', 'r', 'b', 'q', 'sigma', 'eta', 
         'phi', 'barrier_direction', 'knock', 'option', 'option1', 
         'option2', 'option3', 'option4', 'direction', 'value', 
         'ratio', 'refresh', 'price_shift', 'price_shift_type', 
         'vol_shift','ttm_shift', 'rate_shift', 'greek', 'num_sens', 
         'interactive', 'notebook', 'colorscheme', 'colorintensity', 
         'size3d', 'size2d', 'graphtype', 'cash', 'axis', 'spacegrain', 
         'azim', 'elev', 'risk', 'mpl_style'
         ],
     
     # List of Greeks where call and put values are the same
     'df_equal_greeks':[
         'gamma', 'vega', 'vomma', 'vanna', 'zomma', 'speed', 'color', 
         'ultima', 'vega bleed'
         ],
     
     # Payoffs requiring changes to default parameters
     'df_mod_payoffs':[
         'call', 'put', 'collar', 'straddle', 'butterfly', 
         'christmas tree', 'condor', 'iron butterfly', 'iron condor'
         ],
     
     # Those parameters that need changing
     'df_mod_params':[
         'S', 'K', 'K1', 'K2', 'K3', 'K4', 'T', 'T1', 'T2', 'T3', 'T4'
         ],
     
     # Combo parameter values differing from standard defaults
     'df_combo_dict':{'call':{'S':100,
                              'K':100,
                              'K1':100,
                              'T1':0.25},
                      'put':{'S':100,
                             'K':100,
                             'K1':100,
                             'T1':0.25},
                      'collar':{'S':100,
                                'K':100,
                                'K1':98,
                                'K2':102,
                                'T1':0.25,
                                'T2':0.25},
                      'straddle':{'S':100,
                                  'K':100,
                                  'K1':100,
                                  'K2':100,
                                  'T1':0.25,
                                  'T2':0.25},
                      'butterfly':{'S':100,
                                   'K':100,
                                   'K1':95,
                                   'K2':100,
                                   'K3':105,
                                   'T1':0.25,
                                   'T2':0.25,
                                   'T3':0.25},
                      'christmas tree':{'S':100,
                                        'K':100,
                                        'K1':95,
                                        'K2':100,
                                        'K3':105,
                                        'T1':0.25,
                                        'T2':0.25,
                                        'T3':0.25},
                      'condor':{'S':100,
                                'K':100,
                                'K1':90,
                                'K2':95,
                                'K3':100,
                                'K4':105,
                                'T1':0.25,
                                'T2':0.25,
                                'T3':0.25,
                                'T4':0.25},
                      'iron butterfly':{'S':100,
                                        'K':100,
                                        'K1':95,
                                        'K2':100,
                                        'K3':100,
                                        'K4':105,
                                        'T1':0.25,
                                        'T2':0.25,
                                        'T3':0.25,
                                        'T4':0.25},
                      'iron condor':{'S':100,
                                     'K':100,
                                     'K1':90,
                                     'K2':95,
                                     'K3':100,
                                     'K4':105,
                                     'T1':0.25,
                                     'T2':0.25,
                                     'T3':0.25,
                                     'T4':0.25}},
     
     # Dictionary mapping function parameters to x axis labels 
     # for 2D graphs
     'df_x_name_dict':{'price':'SA', 
                       'strike':'SA',
                       'vol':'sigmaA', 
                       'time':'TA'},
     
     # Dictionary mapping scaling parameters to x axis labels 
     # for 2D graphs
     'df_x_scale_dict':{'price':1, 
                        'strike':1,
                        'vol':100, 
                        'time':365},
     
     # Dictionary mapping function parameters to y axis labels 
     # for 2D graphs
     'df_y_name_dict':{'value':'price', 
                       'delta':'delta', 
                       'gamma':'gamma', 
                       'vega':'vega', 
                       'theta':'theta'},
 
     # Dictionary mapping function parameters to axis labels 
     # for 3D graphs
     'df_label_dict':{'price':'Underlying Price',
                      'value':'Theoretical Value',
                      'vol':'Volatility %',
                      'time':'Time to Expiration (Days)',
                      'delta':'Delta',
                      'gamma':'Gamma',
                      'vega':'Vega',
                      'theta':'Theta',
                      'rho':'Rho',
                      'strike':'Strike Price'},
     
     # Ranges of Underlying price and Time to Expiry for 3D 
     # greeks graphs
     'df_3D_chart_ranges':{'price':{'SA_lower':0.8,
                                    'SA_upper':1.2,
                                    'TA_lower':0.01,
                                    'TA_upper':1},
                           'delta':{'SA_lower':0.25,
                                    'SA_upper':1.75,
                                    'TA_lower':0.01,
                                    'TA_upper':2},
                           'gamma':{'SA_lower':0.8,
                                    'SA_upper':1.2,
                                    'TA_lower':0.01,
                                    'TA_upper':5},
                           'vega':{'SA_lower':0.5,
                                   'SA_upper':1.5,
                                   'TA_lower':0.01,
                                   'TA_upper':1},
                           'theta':{'SA_lower':0.8,
                                    'SA_upper':1.2,
                                    'TA_lower':0.01,
                                    'TA_upper':1},
                           'rho':{'SA_lower':0.8,
                                  'SA_upper':1.2,
                                  'TA_lower':0.01,
                                  'TA_upper':0.5},
                           'vomma':{'SA_lower':0.5,
                                    'SA_upper':1.5,
                                    'TA_lower':0.01,
                                    'TA_upper':1},
                           'vanna':{'SA_lower':0.5,
                                    'SA_upper':1.5,
                                    'TA_lower':0.01,
                                    'TA_upper':1},
                           'zomma':{'SA_lower':0.8,
                                    'SA_upper':1.2,
                                    'TA_lower':0.01,
                                    'TA_upper':0.5},
                           'speed':{'SA_lower':0.8,
                                    'SA_upper':1.2,
                                    'TA_lower':0.01,
                                    'TA_upper':0.5},
                           'color':{'SA_lower':0.8,
                                    'SA_upper':1.2,
                                    'TA_lower':0.01,
                                    'TA_upper':0.5},
                           'ultima':{'SA_lower':0.5,
                                     'SA_upper':1.5,
                                     'TA_lower':0.01,
                                     'TA_upper':1},
                           'vega bleed':{'SA_lower':0.5,
                                         'SA_upper':1.5,
                                         'TA_lower':0.01,
                                         'TA_upper':1},
                           'charm':{'SA_lower':0.8,
                                    'SA_upper':1.2,
                                    'TA_lower':0.01,
                                    'TA_upper':0.25}},
     
     # Greek names as function input and individual function 
     # names            
     'df_greek_dict':{'price':'price',
                      'delta':'delta',
                      'gamma':'gamma',
                      'vega':'vega',
                      'theta':'theta',
                      'rho':'rho',
                      'vomma':'vomma',
                      'vanna':'vanna',
                      'zomma':'zomma',
                      'speed':'speed',
                      'color':'color',
                      'ultima':'ultima',
                      'vega bleed':'vega_bleed',
                      'charm':'charm'},
      
     # Parameters to overwrite mpl_style defaults
     'df_mpl_params':{'legend.fontsize': 'x-large',
                      'legend.fancybox':False,
                      'figure.dpi':72,
                      'axes.labelsize': 'medium',
                      'axes.titlesize':'large',
                      'axes.spines.bottom':True,
                      'axes.spines.left':True,
                      'axes.spines.right':True,
                      'axes.spines.top':True,
                      'axes.edgecolor':'black',
                      'axes.titlepad':20,
                      'axes.autolimit_mode':'data',#'round_numbers',
                      'axes.xmargin':0.05,
                      'axes.ymargin':0.05,
                      'axes.linewidth':2,
                      'xtick.labelsize':'medium',
                      'ytick.labelsize':'medium',
                      'xtick.major.pad':10,
                      'ytick.major.pad':10,
                      'lines.linewidth':3.0,
                      'lines.color':'black',
                      'grid.color':'black',
                      'grid.linestyle':':',
                      'font.size':14},
     
     'df_mpl_3d_params':{'axes.facecolor':'w',
                         'axes.labelcolor':'k',
                         'axes.edgecolor':'w',
                         'axes.titlepad':5,
                         'lines.linewidth':0.5,
                         'xtick.labelbottom':True,
                         'ytick.labelleft':True}
     }
